# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalPKReady.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PkPlayerInfo_pb2 as PkPlayerInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x43ommonStateSignalPKReady.proto\x12\nAcFunDanmu\x1a\x12PkPlayerInfo.proto\"J\n\x18\x43ommonStateSignalPKReady\x12\t\n\x01\x61\x18\x01 \x01(\t\x12#\n\x01\x62\x18\x02 \x03(\x0b\x32\x18.AcFunDanmu.PkPlayerInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalPKReady_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALPKREADY._serialized_start=66
  _COMMONSTATESIGNALPKREADY._serialized_end=140
# @@protoc_insertion_point(module_scope)
