            <div class="pagelet_newcomment" style="visibility: visible;">
                <div class="comment-area">
                    <div class="clearfix comm">
                        <div class="columen-left fl">
                            <div id="area-comment" class="block"></div>
                            <div class="ac-pc-comment">
                                <!--标题-->
                                <div class="ac-comment-title">
                                    <div class="area-comm-title-left">
                                        <span class="area-comm-str">评论</span>
                                        <span class="area-comm-number">{{ RAW.commentCountRealValue or RAW.formatCommentCount }}</span>
                                    </div>
                                    <div class="area-comm-title-right">
                                        <a class="area-update update" title="刷新">
                                            <img class="update" src="../../assets/img/refresh-icon.png"> </a>
                                        <a class="area-switch switch area-switch-secondary " title="默认模式">
                                            <img class="switch" src="../../assets/img/mode-icon.png"> </a>
                                        <a class="area-switch switch area-switch-floor hide" title="盖楼模式">
                                            <img class="switch" src="../../assets/img/mode-icon-2.png"> </a>
                                    </div>
                                    <div class="mode-container hide">
                                        <div class="mode-item mode-item-secondary active" data-usemode="SECONDARY">默认模式</div>
                                        <div class="mode-item mode-item-floor " data-usemode="FLOOR">盖楼模式</div>
                                    </div>
                                </div>
                                <!-- 提示 -->
                                <div class="ac-comment-warn"></div>
                                <!--顶部评论框-->
                                <div class="ac-comment-top-editor"><!--editor的div为富文本的承载容器-->
                                    <div class="area-editor area-editor-login">
                                        <p>
                                            <span>去线上</span>
                                            <a class="button btn-login" href="https://www.acfun.cn/login/?returnUrl=https%3A%2F%2Fwww.acfun.cn%2Fv%2Fac{{ v_num }}">登录</a>
                                            <span>啊，离线发什么评论~</span>
                                        </p>
                                    </div>
                                </div>
                                <!--顶部翻页-->
                                <div class="ac-comment-top-pager">
                                    <div id="page-main" style="display: none;">
                                        <div id="pager" class="pager__wrapper">
                                            <a class="pager__btn pager__btn__prev pager__btn__disabled">上一页</a>
                                            <a class="pager__btn pager__btn__selected">1</a>
                                            <a class="pager__btn">2</a>
                                            <a class="pager__btn">3</a>
                                            <a class="pager__btn pager__btn__next">下一页</a>
                                            <div class="pager__input">跳至<input type="text">页</div>
                                        </div>
                                    </div>
                                </div>
                                <div class="ac-comment-loading"></div>
                                <!--评论列表-->
                                <div class="ac-comment-list">
                                    <div class="ac-comment-hot-list" id="comment-hot-list"></div>
                                    <div class="ac-comment-root-list" id="comment-root-list"></div>
                                </div>
                                <!--底部翻页-->
                                <div class="ac-comment-bottom-pager"></div>
                                <!--底部评论框-->
                                <div class="ac-comment-bottom-editor"></div>
                                <!-- 弹窗 -->
                                <div class="ac-comment-toast"></div>
                                <!-- 用户卡片 -->
                                <div class="ac-comment-usercard hide"></div>
                                <!-- dialog -->
                                <div class="ac-comment-dialog"></div>
                                <div class="ac-comment-message"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
