    <link type="text/css" rel="stylesheet" href="../../assets/css/userCard.css"/>
    <div id="usercard">
        <div id="userCard" style="left: 135px; top: 883px;">
            <div class="user-information-head">
                <a class="user-avatar" href="https://www.acfun.cn/u/13215999"><img src="../../member/{{ RAW.user.href }}_avatar"></a>
                <div class="user-profile">
                    <div class="card-user-name">
                        <a class="user-name-item"
                           title="注册于 2018年4月20日(星期五) 12时49分 (Uid:{{ RAW.user.id }})"
                           href="https://www.acfun.cn/u/{{ user.href }}">{{ RAW.user.name }}</a>
                        {% if RAW.user.isContractUp %}
                        <span class="verified-icon monkey-verified-icon" title="AcFun管理员认证"></span>
                        {% endif %}
                        {% if 2 in RAW.user.verifiedTypes %}
                        <span class="verified-icon official-verified-icon" title="AcFun官方认证" style=""></span>
                        {% endif %}
                        {% if 5 in RAW.user.verifiedTypes %}
                        <span class="up-college-verified" style="">
                            <span class="verified-icon up-college-verified-icon"></span>
                            <div class="up-college-verified-content">
                                <span class="up-college-verified-content-text"> 尊贵的阿普学院标志。
                                  <a rel="noopener" class="link" href="//member.acfun.cn/academy" target="_blank">如何获得标志？</a>
                                </span>
                            </div>
                        </span>
                        {% endif %}
                        <span class="verified-icon avi-verified-icon" title="AVI虚拟偶像标识" style="display:none"></span>
                        <span class="verified-icon advanced-danmaku-verified-icon" title="高弹达人标识" style="display:none"></span>
                    </div>
                    <p class="user-description">{{ RAW.user.signature }}</p></div>
            </div>
            <ul class="user-active-data clearfix">
                <li><span class="item">关注</span><span class="followCount count">{{ RAW.user.followingCount }}</span></li>
                <li><span class="item">粉丝</span><span class="fansCount count">{{ RAW.user.fanCount }}</span></li>
                <li><span class="item">投稿</span><span class="contributeCount count">{{ RAW.user.contributeCount }}</span></li>
            </ul>
            <div class="user-iteractive">
                <div class="user-to-follow not-follow">关注</div>
                <a class="user-to-message" href="https://message.acfun.cn/im?targetid={{ user.id }}">私信</a></div>
        </div>
    </div>
