<div id="pagelet_toolbar" style="visibility: visible;">
    <div id="toolbar" class="toolbar showAll">
        <div id="to-lab" title="实验室" class="icon icon-to-lab tool-item tool-to-lab" style="display: none;">
            <span class="lab">实验室</span></div>
        <a href="#area-comment">
            <div id="to-comm" title="前往评论" class="icon icon-to-comm tool-item tool-to-comm">
                <span class="pts">{{ RAW.commentCountRealValue or RAW.formatCommentCount }}</span></div>
        </a>
        <a href="#main">
            <div id="to-top" title="返回顶部" class="icon icon-arrow-slim-up tool-item tool-to-top toBottom"></div>
        </a>
        <div id="comment-lastPage" title="上一页评论" class="icon icon-to-comm tool-item tool-to-comm" style="display: none">
            <span class="pts">上一页</span></div>
        <div id="comment-nextPage" title="下一页评论" class="icon icon-to-comm tool-item tool-to-comm" style="display: none">
            <span class="pts">下一页</span></div>
    </div>
</div>
