# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinStatus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15GroupJoinStatus.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*[\n\x0fGroupJoinStatus\x12\x11\n\rINVITE_STATUS\x10\x00\x12\t\n\x05\x41GREE\x10\x01\x12\n\n\x06REFUSE\x10\x02\x12\x0c\n\x08\x41PPLYING\x10\x03\x12\x10\n\x0cOUT_OF_GROUP\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinStatus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINSTATUS._serialized_start=54
  _GROUPJOINSTATUS._serialized_end=145
# @@protoc_insertion_point(module_scope)
